============
Installation
============

At the command line::

    $ pip install vmware-nsx 

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv vmware-nsx
    $ pip install vmware-nsx
